/**
 * 
 * 公会详情
 */

import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import { Button, Card, Descriptions, Table, DatePicker, Input } from 'antd'
import styles from './FamilyDetails.less'
import router from 'umi/router'
import { getAgentDetail } from './api'
import ZImage from 'react-zmage'
import { getStatusStr } from './common'
import { getDate } from '@/utils/base'
import { connect } from 'dva'
import Decimal from 'decimal.js'
const { RangePicker } = DatePicker
const _cardStyle = {
  marginBottom: 10
}
const Column = Table.Column
const list = [
  {id: 1, time: new Date().getTime(), money: 3838 },
  {id: 2, time: new Date().getTime(), money: 3838 },
  {id: 3, time: new Date().getTime(), money: 3838 },
]
@connect(({ user }) => ({
  currentUser: user.currentUser
}))
class FamilyDetails extends Component {
  constructor (props) {
    super(props)
    this.state = {
      agentId: props.currentUser.agentId
    }
  }
  componentDidMount () {
    this.getDetails()
  }
  // 获取数据
  getDetails = async () => {
    const { agentId } = this.state
    const _state = {
      loading: false
    }
  
    try {
      this.setState({ loading: true })
      const { code, data } = await getAgentDetail({ agentId })
      if (code === 'OK' && data) {

        const { 
          agentName, agentLogo, agentNo, agentIntro, president, presidentName, status,
          createTime, presidentPhone, anchorRatio, agentRatio
        } = data
        // 公会名称
        _state.agentName = agentName
        // 公会编号
        _state.agentNo = agentNo
        // 公会id
        _state.agentId = agentId
        // 公会简介
        _state.agentIntro = agentIntro
        // 工会分成比例
        _state.agentRatio = agentRatio || agentRatio === 0 ? new Decimal(agentRatio).mul(new Decimal(100)).toNumber() : undefined
        // 主播默认提成比例
        _state.anchorRatio = anchorRatio || anchorRatio === 0 ? new Decimal(anchorRatio).mul(new Decimal(100)).toNumber() : undefined
        // 公会状态
        _state.status = status
        // 公会
        _state.agentLogo = agentLogo
        // 会长姓名
        _state.presidentName = presidentName
        // 会长id
        _state.president = president
        // 会长联系方式
        _state.presidentPhone = presidentPhone
        // 创建时间
        _state.createTime = createTime
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }
  goDetails = () => {
    router.push({
      pathname: '/myfamily/liveinfo'
    })
  }
  render () {
    const { 
      agentLogo, agentName, agentNo, agentId, status, createTime, presidentName,
      president, presidentPhone, agentIntro, anchorRatio, agentRatio
    } = this.state
    return (
      <PageHeaderWrapper 
        title='公会详情'
        extra={
          <div>
            <Button
              onClick={router.goBack}
              type='default'
              icon='left'
            >返回</Button>
          </div>
        }
      >
        <Card style={_cardStyle} title='公会信息'>
          <Descriptions bordered>
            <Descriptions.Item label='公会头像'>
              <ZImage src={agentLogo} style={{width: 80}}/>
            </Descriptions.Item>
            <Descriptions.Item label='公会名称' span={2}>
              {agentName}
            </Descriptions.Item>
            <Descriptions.Item label='公会ID'>
              {agentId}
            </Descriptions.Item>
            <Descriptions.Item label='公会编号'>
              {agentNo}
            </Descriptions.Item>
            <Descriptions.Item label='公会状态'>
              {getStatusStr(status)}
            </Descriptions.Item>
            <Descriptions.Item label='公会简介' span={3}>
              {agentIntro}
            </Descriptions.Item>
            <Descriptions.Item label='会长昵称'>
              {presidentName}
            </Descriptions.Item>
            <Descriptions.Item label='会长ID'>
              {president}
            </Descriptions.Item>
            <Descriptions.Item label='会长联系方式'>
              {presidentPhone}
            </Descriptions.Item>
            <Descriptions.Item label='公会提成比例'>
              {agentRatio || agentRatio === 0 ? `${agentRatio}%` : '-'}
            </Descriptions.Item>
            <Descriptions.Item label='主播默认提成比例' span={2}>
              {anchorRatio || anchorRatio === 0 ? `${anchorRatio}%` : '-'}
            </Descriptions.Item>
            <Descriptions.Item label='创建时间'>
              {createTime ? getDate(+createTime, 'yyyy-MM-dd') : '-'}
            </Descriptions.Item>
          </Descriptions>
        </Card>
        <Card 
          style={_cardStyle} 
          title='公会流水数据'
          hidden
        >
          <div className={styles['filters-wrap']}>
            <div className={styles['filters-content']}>
              <div className={styles['filters-item']}> 
                <span>选择日期: </span>
                <RangePicker />
              </div>
            </div>
            <Button type='primary' icon='download'>导出流水</Button>
          </div>
          <Table
            bordered
            dataSource={list}
            rowKey='id'
          >
            <Column 
              title='时间'
              dataIndex='time'
              key='time'
            />
            <Column 
              title='结算金额'
              dataIndex='money'
              key='money'
            />
          </Table>
        </Card>
        <Card 
          title='主播列表/开播数据'
          hidden
        >
          <div className={styles['filters-wrap']}>
            <div className={styles['filters-content']}>
              <div className={styles['filters-item']}> 
                <span>选择日期: </span>
                <RangePicker />
              </div>
              <div className={styles['filters-item']}> 
                <span>搜索主播: </span>
                <Input 
                  placeholder='搜索主播'
                />
              </div>
              <div className={styles['filters-item']}> 
                <Button
                  icon='search'
                  type='primary'
                >搜索</Button>
              </div>
            </div>
            <Button type='primary' icon='download'>导出数据</Button>
          </div>
          <Table
            bordered
            dataSource={list}
            rowKey='id'
          >
            <Column 
              title='时间'
              dataIndex='time'
              key='time'
            />
            <Column 
              title='星芽号'
              dataIndex='money'
              key='money'
            />
            <Column 
              title='昵称'
              dataIndex='nickName'
              key='nickName'
            />
            <Column 
              title='等级'
              dataIndex='leval'
              key='leval'
            />
            <Column 
              title='性别'
              dataIndex='gender'
              key='gender'
            />
            <Column 
              title='粉丝数量'
              dataIndex='fansNumber'
              key='fansNumber'
            />
            <Column 
              title='直播有效天数'
              dataIndex='dates'
              key='dates'
            />
            <Column 
              title='流水总计'
              dataIndex='total'
              key='total'
            />
            <Column 
              title='直播时长'
              dataIndex='hourses'
              key='hourses'
            />
            <Column 
              title='操作'
              dataIndex='action'
              key='action'
              render={(text, record) => (
                <div>
                  <a href="#" onClick={e => {
                    e.preventDefault()
                    this.goDetails(record)
                  }}>详情</a>
                </div>
              )}
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default FamilyDetails
